==> qmmp_0.2.3.orig.tar.gz: qmmp-0.2.3/src/plugins/General/statusicon/translations/statusicon_plugin_uk_UA.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1" language="uk">
<defaultcodec></defaultcodec>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="13"/>
        <source>Status Icon Plugin Settings</source>
        <translation>Налаштування модуля Status Icon</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="19"/>
        <source>Show message</source>
        <translation>Показувати повідомлення</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="26"/>
        <source>Show tooltip</source>
        <translation>Показувати спливаючу підказку</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="33"/>
        <source>Message delay, ms:</source>
        <translation>Затримка повідомлення, мс:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="89"/>
        <source>OK</source>
        <translation>Застосувати</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="96"/>
        <source>Cancel</source>
        <translation>Відмінити</translation>
    </message>
</context>
<context>
    <name>StatusIcon</name>
    <message>
        <location filename="../statusicon.cpp" line="39"/>
        <source>Play</source>
        <translation>Грати</translation>
    </message>
    <message>
        <location filename="../statusicon.cpp" line="40"/>
        <source>Pause</source>
        <translation>Пауза</translation>
    </message>
    <message>
        <location filename="../statusicon.cpp" line="41"/>
        <source>Stop</source>
        <translation>Стоп</translation>
    </message>
    <message>
        <location filename="../statusicon.cpp" line="42"/>
        <source>Next</source>
        <translation>Вперед</translation>
    </message>
    <message>
        <location filename="../statusicon.cpp" line="43"/>
        <source>Previous</source>
        <translation>Назад</translation>
    </message>
    <message>
        <location filename="../statusicon.cpp" line="45"/>
        <source>Exit</source>
        <translation>Вихід</translation>
    </message>
    <message>
        <location filename="../statusicon.cpp" line="96"/>
        <source>Now Playing</source>
        <translation>Зараз грає</translation>
    </message>
</context>
<context>
    <name>StatusIconFactory</name>
    <message>
        <location filename="../statusiconfactory.cpp" line="30"/>
        <source>Status Icon Plugin</source>
        <translation>Модуль Status Icon</translation>
    </message>
    <message>
        <location filename="../statusiconfactory.cpp" line="49"/>
        <source>About Status Icon Plugin</source>
        <translation>Про модуль Status Icon</translation>
    </message>
    <message>
        <location filename="../statusiconfactory.cpp" line="50"/>
        <source>Qmmp Status Icon Plugin</source>
        <translation>Модуль Status Icon для Qmmp</translation>
    </message>
    <message>
        <location filename="../statusiconfactory.cpp" line="51"/>
        <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Розробник: Ілля Котов &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
</TS>

==> qmmp_0.3.1.orig.tar.gz: qmmp-0.3.1/src/plugins/General/statusicon/translations/statusicon_plugin_uk_UA.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="uk">
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>Status Icon Plugin Settings</source>
        <translation>Налаштування модуля Status Icon</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="20"/>
        <source>Show message</source>
        <translation>Показувати повідомлення</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="27"/>
        <source>Show tooltip</source>
        <translation>Показувати спливаючу підказку</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="34"/>
        <source>Message delay, ms:</source>
        <translation>Затримка повідомлення, мс:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="86"/>
        <source>Use standard icons</source>
        <translation>Використовувати стандартну іконку</translation>
    </message>
</context>
<context>
    <name>StatusIcon</name>
    <message>
        <location filename="../statusicon.cpp" line="46"/>
        <source>Play</source>
        <translation>Грати</translation>
    </message>
    <message>
        <location filename="../statusicon.cpp" line="47"/>
        <source>Pause</source>
        <translation>Пауза</translation>
    </message>
    <message>
        <location filename="../statusicon.cpp" line="48"/>
        <source>Stop</source>
        <translation>Стоп</translation>
    </message>
    <message>
        <location filename="../statusicon.cpp" line="49"/>
        <source>Next</source>
        <translation>Вперед</translation>
    </message>
    <message>
        <location filename="../statusicon.cpp" line="50"/>
        <source>Previous</source>
        <translation>Назад</translation>
    </message>
    <message>
        <location filename="../statusicon.cpp" line="52"/>
        <source>Exit</source>
        <translation>Вихід</translation>
    </message>
    <message>
        <location filename="../statusicon.cpp" line="127"/>
        <source>Now Playing</source>
        <translation>Зараз грає</translation>
    </message>
</context>
<context>
    <name>StatusIconFactory</name>
    <message>
        <location filename="../statusiconfactory.cpp" line="30"/>
        <source>Status Icon Plugin</source>
        <translation>Модуль Status Icon</translation>
    </message>
    <message>
        <location filename="../statusiconfactory.cpp" line="50"/>
        <source>About Status Icon Plugin</source>
        <translation>Про модуль Status Icon</translation>
    </message>
    <message>
        <location filename="../statusiconfactory.cpp" line="51"/>
        <source>Qmmp Status Icon Plugin</source>
        <translation>Модуль Status Icon для Qmmp</translation>
    </message>
    <message>
        <location filename="../statusiconfactory.cpp" line="52"/>
        <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Розробник: Ілля Котов &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
</TS>
